==> PyMeasure-0.8.0.tar.gz: PyMeasure-0.8.0/tests/adapters/test_adapter.py <==
#
# This file is part of the PyMeasure package.
#
# Copyright (c) 2013-2020 PyMeasure Developers
#
# Permission is hereby granted, free of charge, to any person obtaining a copy
# of this software and associated documentation files (the "Software"), to deal
# in the Software without restriction, including without limitation the rights
# to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
# copies of the Software, and to permit persons to whom the Software is
# furnished to do so, subject to the following conditions:
#
# The above copyright notice and this permission notice shall be included in
# all copies or substantial portions of the Software.
#
# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
# IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
# FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
# AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
# LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
# OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
# THE SOFTWARE.
#

import logging

from pymeasure.adapters import FakeAdapter

log = logging.getLogger(__name__)
log.addHandler(logging.NullHandler())


def test_adapter_values():
    a = FakeAdapter()
    assert a.values("5,6,7") == [5, 6, 7]
    assert a.values("5,6,7", cast=str) == ['5', '6', '7']
    assert a.values("X,Y,Z") == ['X', 'Y', 'Z']
    assert a.values("X,Y,Z", cast=str) == ['X', 'Y', 'Z']
    assert a.values("X.Y.Z", separator='.') == ['X', 'Y', 'Z']

==> PyMeasure-0.10.0.tar.gz: PyMeasure-0.10.0/tests/adapters/test_adapter.py <==
#
# This file is part of the PyMeasure package.
#
# Copyright (c) 2013-2022 PyMeasure Developers
#
# Permission is hereby granted, free of charge, to any person obtaining a copy
# of this software and associated documentation files (the "Software"), to deal
# in the Software without restriction, including without limitation the rights
# to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
# copies of the Software, and to permit persons to whom the Software is
# furnished to do so, subject to the following conditions:
#
# The above copyright notice and this permission notice shall be included in
# all copies or substantial portions of the Software.
#
# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
# IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
# FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
# AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
# LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
# OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
# THE SOFTWARE.
#

import logging

from pymeasure.adapters import FakeAdapter

log = logging.getLogger(__name__)
log.addHandler(logging.NullHandler())


def test_adapter_values():
    a = FakeAdapter()
    assert a.values("5,6,7") == [5, 6, 7]
    assert a.values("5,6,7", cast=str) == ['5', '6', '7']
    assert a.values("X,Y,Z") == ['X', 'Y', 'Z']
    assert a.values("X,Y,Z", cast=str) == ['X', 'Y', 'Z']
    assert a.values("X.Y.Z", separator='.') == ['X', 'Y', 'Z']


def test_adapter_preprocess_reply():
    a = FakeAdapter(preprocess_reply=lambda v: v[1:])
    assert a.values("R42.1") == [42.1]
    assert a.values("A4,3,2") == [4, 3, 2]
    assert a.values("TV 1", preprocess_reply=lambda v: v.split()[0]) == ['TV']
    assert a.values("15", preprocess_reply=lambda v: v) == [15]
    a = FakeAdapter()
    assert a.values("V 3.4", preprocess_reply=lambda v: v.split()[1]) == [3.4]
